-------------------------------------------------------------------------------
-- Title      : Font 8x8
-- Project    : 
-------------------------------------------------------------------------------
-- File       : font8x8.vhd
-- Author     : 
-- Company    : 
-- Created    : 2007-10-16
-- Last update: 2009-05-29
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: 
-------------------------------------------------------------------------------
-- Copyright (c) 2007 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2007-10-16  1.0      Kest     Created
-------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.all;
use ieee.numeric_std.all;

entity font8x8 is
  port (
    nReset : in std_logic;
    clk    : in std_logic;
    char   : in std_logic_vector(7 downto 0);
    char_line : in std_logic_vector(2 downto 0);
    data_out : out std_logic_vector(7 downto 0)
    );
end font8x8;

architecture behave of font8x8 is

  type tChar is array(0 to 7) of std_logic_vector(7 downto 0);
  type tFont is array(0 to 255) of tChar;
  
  constant font : tFont := (
    (x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00"),
    (x"7e", x"81", x"a5", x"81", x"bd", x"99", x"81", x"7e"),
    (x"7e", x"ff", x"db", x"ff", x"c3", x"e7", x"ff", x"7e"),
    (x"6c", x"fe", x"fe", x"fe", x"7c", x"38", x"10", x"00"),
    (x"10", x"38", x"7c", x"fe", x"7c", x"38", x"10", x"00"),
    (x"38", x"7c", x"38", x"fe", x"fe", x"d6", x"10", x"38"),
    (x"10", x"38", x"7c", x"fe", x"fe", x"7c", x"10", x"38"),
    (x"00", x"00", x"18", x"3c", x"3c", x"18", x"00", x"00"),
    (x"ff", x"ff", x"e7", x"c3", x"c3", x"e7", x"ff", x"ff"),
    (x"00", x"3c", x"66", x"42", x"42", x"66", x"3c", x"00"),
    (x"ff", x"c3", x"99", x"bd", x"bd", x"99", x"c3", x"ff"),
    (x"0f", x"07", x"0f", x"7d", x"cc", x"cc", x"cc", x"78"),
    (x"3c", x"66", x"66", x"66", x"3c", x"18", x"7e", x"18"),
    (x"3f", x"33", x"3f", x"30", x"30", x"70", x"f0", x"e0"),
    (x"7f", x"63", x"7f", x"63", x"63", x"67", x"e6", x"c0"),
    (x"18", x"db", x"3c", x"e7", x"e7", x"3c", x"db", x"18"),
    (x"80", x"e0", x"f8", x"fe", x"f8", x"e0", x"80", x"00"),
    (x"02", x"0e", x"3e", x"fe", x"3e", x"0e", x"02", x"00"),
    (x"18", x"3c", x"7e", x"18", x"18", x"7e", x"3c", x"18"),
    (x"66", x"66", x"66", x"66", x"66", x"00", x"66", x"00"),
    (x"7f", x"db", x"db", x"7b", x"1b", x"1b", x"1b", x"00"),
    (x"3e", x"61", x"3c", x"66", x"66", x"3c", x"86", x"7c"),
    (x"00", x"00", x"00", x"00", x"7e", x"7e", x"7e", x"00"),
    (x"18", x"3c", x"7e", x"18", x"7e", x"3c", x"18", x"ff"),
    (x"18", x"3c", x"7e", x"18", x"18", x"18", x"18", x"00"),
    (x"18", x"18", x"18", x"18", x"7e", x"3c", x"18", x"00"),
    (x"00", x"18", x"0c", x"fe", x"0c", x"18", x"00", x"00"),
    (x"00", x"30", x"60", x"fe", x"60", x"30", x"00", x"00"),
    (x"00", x"00", x"c0", x"c0", x"c0", x"fe", x"00", x"00"),
    (x"00", x"24", x"66", x"ff", x"66", x"24", x"00", x"00"),
    (x"00", x"18", x"3c", x"7e", x"ff", x"ff", x"00", x"00"),
    (x"00", x"ff", x"ff", x"7e", x"3c", x"18", x"00", x"00"),
    (x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00"),
    (x"18", x"3c", x"3c", x"18", x"18", x"00", x"18", x"00"),
    (x"66", x"66", x"24", x"00", x"00", x"00", x"00", x"00"),
    (x"6c", x"6c", x"fe", x"6c", x"fe", x"6c", x"6c", x"00"),
    (x"18", x"3e", x"60", x"3c", x"06", x"7c", x"18", x"00"),
    (x"00", x"c6", x"cc", x"18", x"30", x"66", x"c6", x"00"),
    (x"38", x"6c", x"38", x"76", x"dc", x"cc", x"76", x"00"),
    (x"18", x"18", x"30", x"00", x"00", x"00", x"00", x"00"),
    (x"0c", x"18", x"30", x"30", x"30", x"18", x"0c", x"00"),
    (x"30", x"18", x"0c", x"0c", x"0c", x"18", x"30", x"00"),
    (x"00", x"66", x"3c", x"ff", x"3c", x"66", x"00", x"00"),
    (x"00", x"18", x"18", x"7e", x"18", x"18", x"00", x"00"),
    (x"00", x"00", x"00", x"00", x"00", x"18", x"18", x"30"),
    (x"00", x"00", x"00", x"7e", x"00", x"00", x"00", x"00"),
    (x"00", x"00", x"00", x"00", x"00", x"18", x"18", x"00"),
    (x"06", x"0c", x"18", x"30", x"60", x"c0", x"80", x"00"),
    (x"38", x"6c", x"c6", x"d6", x"c6", x"6c", x"38", x"00"),
    (x"18", x"38", x"18", x"18", x"18", x"18", x"7e", x"00"),
    (x"7c", x"c6", x"06", x"1c", x"30", x"66", x"fe", x"00"),
    (x"7c", x"c6", x"06", x"3c", x"06", x"c6", x"7c", x"00"),
    (x"1c", x"3c", x"6c", x"cc", x"fe", x"0c", x"1e", x"00"),
    (x"fe", x"c0", x"c0", x"fc", x"06", x"c6", x"7c", x"00"),
    (x"38", x"60", x"c0", x"fc", x"c6", x"c6", x"7c", x"00"),
    (x"fe", x"c6", x"0c", x"18", x"30", x"30", x"30", x"00"),
    (x"7c", x"c6", x"c6", x"7c", x"c6", x"c6", x"7c", x"00"),
    (x"7c", x"c6", x"c6", x"7e", x"06", x"0c", x"78", x"00"),
    (x"00", x"18", x"18", x"00", x"00", x"18", x"18", x"00"),
    (x"00", x"18", x"18", x"00", x"00", x"18", x"18", x"30"),
    (x"06", x"0c", x"18", x"30", x"18", x"0c", x"06", x"00"),
    (x"00", x"00", x"7e", x"00", x"00", x"7e", x"00", x"00"),
    (x"60", x"30", x"18", x"0c", x"18", x"30", x"60", x"00"),
    (x"7c", x"c6", x"0c", x"18", x"18", x"00", x"18", x"00"),
    (x"7c", x"c6", x"de", x"de", x"de", x"c0", x"78", x"00"),
    (x"38", x"6c", x"c6", x"fe", x"c6", x"c6", x"c6", x"00"),
    (x"fc", x"66", x"66", x"7c", x"66", x"66", x"fc", x"00"),
    (x"3c", x"66", x"c0", x"c0", x"c0", x"66", x"3c", x"00"),
    (x"f8", x"6c", x"66", x"66", x"66", x"6c", x"f8", x"00"),
    (x"fe", x"62", x"68", x"78", x"68", x"62", x"fe", x"00"),
    (x"fe", x"62", x"68", x"78", x"68", x"60", x"f0", x"00"),
    (x"3c", x"66", x"c0", x"c0", x"ce", x"66", x"3a", x"00"),
    (x"c6", x"c6", x"c6", x"fe", x"c6", x"c6", x"c6", x"00"),
    (x"3c", x"18", x"18", x"18", x"18", x"18", x"3c", x"00"),
    (x"1e", x"0c", x"0c", x"0c", x"cc", x"cc", x"78", x"00"),
    (x"e6", x"66", x"6c", x"78", x"6c", x"66", x"e6", x"00"),
    (x"f0", x"60", x"60", x"60", x"62", x"66", x"fe", x"00"),
    (x"c6", x"ee", x"fe", x"fe", x"d6", x"c6", x"c6", x"00"),
    (x"c6", x"e6", x"f6", x"de", x"ce", x"c6", x"c6", x"00"),
    (x"7c", x"c6", x"c6", x"c6", x"c6", x"c6", x"7c", x"00"),
    (x"fc", x"66", x"66", x"7c", x"60", x"60", x"f0", x"00"),
    (x"7c", x"c6", x"c6", x"c6", x"c6", x"ce", x"7c", x"0e"),
    (x"fc", x"66", x"66", x"7c", x"6c", x"66", x"e6", x"00"),
    (x"3c", x"66", x"30", x"18", x"0c", x"66", x"3c", x"00"),
    (x"7e", x"7e", x"5a", x"18", x"18", x"18", x"3c", x"00"),
    (x"c6", x"c6", x"c6", x"c6", x"c6", x"c6", x"7c", x"00"),
    (x"c6", x"c6", x"c6", x"c6", x"c6", x"6c", x"38", x"00"),
    (x"c6", x"c6", x"c6", x"d6", x"d6", x"fe", x"6c", x"00"),
    (x"c6", x"c6", x"6c", x"38", x"6c", x"c6", x"c6", x"00"),
    (x"66", x"66", x"66", x"3c", x"18", x"18", x"3c", x"00"),
    (x"fe", x"c6", x"8c", x"18", x"32", x"66", x"fe", x"00"),
    (x"3c", x"30", x"30", x"30", x"30", x"30", x"3c", x"00"),
    (x"c0", x"60", x"30", x"18", x"0c", x"06", x"02", x"00"),
    (x"3c", x"0c", x"0c", x"0c", x"0c", x"0c", x"3c", x"00"),
    (x"10", x"38", x"6c", x"c6", x"00", x"00", x"00", x"00"),
    (x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"ff"),
    (x"30", x"18", x"0c", x"00", x"00", x"00", x"00", x"00"),
    (x"00", x"00", x"78", x"0c", x"7c", x"cc", x"76", x"00"),
    (x"e0", x"60", x"7c", x"66", x"66", x"66", x"dc", x"00"),
    (x"00", x"00", x"7c", x"c6", x"c0", x"c6", x"7c", x"00"),
    (x"1c", x"0c", x"7c", x"cc", x"cc", x"cc", x"76", x"00"),
    (x"00", x"00", x"7c", x"c6", x"fe", x"c0", x"7c", x"00"),
    (x"3c", x"66", x"60", x"f8", x"60", x"60", x"f0", x"00"),
    (x"00", x"00", x"76", x"cc", x"cc", x"7c", x"0c", x"f8"),
    (x"e0", x"60", x"6c", x"76", x"66", x"66", x"e6", x"00"),
    (x"18", x"00", x"38", x"18", x"18", x"18", x"3c", x"00"),
    (x"06", x"00", x"06", x"06", x"06", x"66", x"66", x"3c"),
    (x"e0", x"60", x"66", x"6c", x"78", x"6c", x"e6", x"00"),
    (x"38", x"18", x"18", x"18", x"18", x"18", x"3c", x"00"),
    (x"00", x"00", x"ec", x"fe", x"d6", x"d6", x"d6", x"00"),
    (x"00", x"00", x"dc", x"66", x"66", x"66", x"66", x"00"),
    (x"00", x"00", x"7c", x"c6", x"c6", x"c6", x"7c", x"00"),
    (x"00", x"00", x"dc", x"66", x"66", x"7c", x"60", x"f0"),
    (x"00", x"00", x"76", x"cc", x"cc", x"7c", x"0c", x"1e"),
    (x"00", x"00", x"dc", x"76", x"60", x"60", x"f0", x"00"),
    (x"00", x"00", x"7e", x"c0", x"7c", x"06", x"fc", x"00"),
    (x"30", x"30", x"fc", x"30", x"30", x"36", x"1c", x"00"),
    (x"00", x"00", x"cc", x"cc", x"cc", x"cc", x"76", x"00"),
    (x"00", x"00", x"c6", x"c6", x"c6", x"6c", x"38", x"00"),
    (x"00", x"00", x"c6", x"d6", x"d6", x"fe", x"6c", x"00"),
    (x"00", x"00", x"c6", x"6c", x"38", x"6c", x"c6", x"00"),
    (x"00", x"00", x"c6", x"c6", x"c6", x"7e", x"06", x"fc"),
    (x"00", x"00", x"7e", x"4c", x"18", x"32", x"7e", x"00"),
    (x"0e", x"18", x"18", x"70", x"18", x"18", x"0e", x"00"),
    (x"18", x"18", x"18", x"18", x"18", x"18", x"18", x"00"),
    (x"70", x"18", x"18", x"0e", x"18", x"18", x"70", x"00"),
    (x"76", x"dc", x"00", x"00", x"00", x"00", x"00", x"00"),
    (x"00", x"10", x"38", x"6c", x"c6", x"c6", x"fe", x"00"),
    (x"7c", x"c6", x"c0", x"c0", x"c6", x"7c", x"0c", x"78"),
    (x"cc", x"00", x"cc", x"cc", x"cc", x"cc", x"76", x"00"),
    (x"0c", x"18", x"7c", x"c6", x"fe", x"c0", x"7c", x"00"),
    (x"7c", x"82", x"78", x"0c", x"7c", x"cc", x"76", x"00"),
    (x"c6", x"00", x"78", x"0c", x"7c", x"cc", x"76", x"00"),
    (x"30", x"18", x"78", x"0c", x"7c", x"cc", x"76", x"00"),
    (x"30", x"30", x"78", x"0c", x"7c", x"cc", x"76", x"00"),
    (x"00", x"00", x"7e", x"c0", x"c0", x"7e", x"0c", x"38"),
    (x"7c", x"82", x"7c", x"c6", x"fe", x"c0", x"7c", x"00"),
    (x"c6", x"00", x"7c", x"c6", x"fe", x"c0", x"7c", x"00"),
    (x"30", x"18", x"7c", x"c6", x"fe", x"c0", x"7c", x"00"),
    (x"66", x"00", x"38", x"18", x"18", x"18", x"3c", x"00"),
    (x"7c", x"82", x"38", x"18", x"18", x"18", x"3c", x"00"),
    (x"30", x"18", x"00", x"38", x"18", x"18", x"3c", x"00"),
    (x"c6", x"38", x"6c", x"c6", x"fe", x"c6", x"c6", x"00"),
    (x"38", x"6c", x"7c", x"c6", x"fe", x"c6", x"c6", x"00"),
    (x"18", x"30", x"fe", x"c0", x"f8", x"c0", x"fe", x"00"),
    (x"00", x"00", x"7e", x"18", x"7e", x"d8", x"7e", x"00"),
    (x"3e", x"6c", x"cc", x"fe", x"cc", x"cc", x"ce", x"00"),
    (x"7c", x"82", x"7c", x"c6", x"c6", x"c6", x"7c", x"00"),
    (x"c6", x"00", x"7c", x"c6", x"c6", x"c6", x"7c", x"00"),
    (x"30", x"18", x"7c", x"c6", x"c6", x"c6", x"7c", x"00"),
    (x"78", x"84", x"00", x"cc", x"cc", x"cc", x"76", x"00"),
    (x"60", x"30", x"cc", x"cc", x"cc", x"cc", x"76", x"00"),
    (x"c6", x"00", x"c6", x"c6", x"c6", x"7e", x"06", x"fc"),
    (x"c6", x"38", x"6c", x"c6", x"c6", x"6c", x"38", x"00"),
    (x"c6", x"00", x"c6", x"c6", x"c6", x"c6", x"7c", x"00"),
    (x"18", x"18", x"7e", x"c0", x"c0", x"7e", x"18", x"18"),
    (x"38", x"6c", x"64", x"f0", x"60", x"66", x"fc", x"00"),
    (x"66", x"66", x"3c", x"7e", x"18", x"7e", x"18", x"18"),
    (x"f8", x"cc", x"cc", x"fa", x"c6", x"cf", x"c6", x"c7"),
    (x"0e", x"1b", x"18", x"3c", x"18", x"d8", x"70", x"00"),
    (x"18", x"30", x"78", x"0c", x"7c", x"cc", x"76", x"00"),
    (x"0c", x"18", x"00", x"38", x"18", x"18", x"3c", x"00"),
    (x"0c", x"18", x"7c", x"c6", x"c6", x"c6", x"7c", x"00"),
    (x"18", x"30", x"cc", x"cc", x"cc", x"cc", x"76", x"00"),
    (x"76", x"dc", x"00", x"dc", x"66", x"66", x"66", x"00"),
    (x"76", x"dc", x"00", x"e6", x"f6", x"de", x"ce", x"00"),
    (x"3c", x"6c", x"6c", x"3e", x"00", x"7e", x"00", x"00"),
    (x"38", x"6c", x"6c", x"38", x"00", x"7c", x"00", x"00"),
    (x"18", x"00", x"18", x"18", x"30", x"63", x"3e", x"00"),
    (x"00", x"00", x"00", x"fe", x"c0", x"c0", x"00", x"00"),
    (x"00", x"00", x"00", x"fe", x"06", x"06", x"00", x"00"),
    (x"63", x"e6", x"6c", x"7e", x"33", x"66", x"cc", x"0f"),
    (x"63", x"e6", x"6c", x"7a", x"36", x"6a", x"df", x"06"),
    (x"18", x"00", x"18", x"18", x"3c", x"3c", x"18", x"00"),
    (x"00", x"33", x"66", x"cc", x"66", x"33", x"00", x"00"),
    (x"00", x"cc", x"66", x"33", x"66", x"cc", x"00", x"00"),
    (x"22", x"88", x"22", x"88", x"22", x"88", x"22", x"88"),
    (x"55", x"aa", x"55", x"aa", x"55", x"aa", x"55", x"aa"),
    (x"77", x"dd", x"77", x"dd", x"77", x"dd", x"77", x"dd"),
    (x"18", x"18", x"18", x"18", x"18", x"18", x"18", x"18"),
    (x"18", x"18", x"18", x"18", x"f8", x"18", x"18", x"18"),
    (x"18", x"18", x"f8", x"18", x"f8", x"18", x"18", x"18"),
    (x"36", x"36", x"36", x"36", x"f6", x"36", x"36", x"36"),
    (x"00", x"00", x"00", x"00", x"fe", x"36", x"36", x"36"),
    (x"00", x"00", x"f8", x"18", x"f8", x"18", x"18", x"18"),
    (x"36", x"36", x"f6", x"06", x"f6", x"36", x"36", x"36"),
    (x"36", x"36", x"36", x"36", x"36", x"36", x"36", x"36"),
    (x"00", x"00", x"fe", x"06", x"f6", x"36", x"36", x"36"),
    (x"36", x"36", x"f6", x"06", x"fe", x"00", x"00", x"00"),
    (x"36", x"36", x"36", x"36", x"fe", x"00", x"00", x"00"),
    (x"18", x"18", x"f8", x"18", x"f8", x"00", x"00", x"00"),
    (x"00", x"00", x"00", x"00", x"f8", x"18", x"18", x"18"),
    (x"18", x"18", x"18", x"18", x"1f", x"00", x"00", x"00"),
    (x"18", x"18", x"18", x"18", x"ff", x"00", x"00", x"00"),
    (x"00", x"00", x"00", x"00", x"ff", x"18", x"18", x"18"),
    (x"18", x"18", x"18", x"18", x"1f", x"18", x"18", x"18"),
    (x"00", x"00", x"00", x"00", x"ff", x"00", x"00", x"00"),
    (x"18", x"18", x"18", x"18", x"ff", x"18", x"18", x"18"),
    (x"18", x"18", x"1f", x"18", x"1f", x"18", x"18", x"18"),
    (x"36", x"36", x"36", x"36", x"37", x"36", x"36", x"36"),
    (x"36", x"36", x"37", x"30", x"3f", x"00", x"00", x"00"),
    (x"00", x"00", x"3f", x"30", x"37", x"36", x"36", x"36"),
    (x"36", x"36", x"f7", x"00", x"ff", x"00", x"00", x"00"),
    (x"00", x"00", x"ff", x"00", x"f7", x"36", x"36", x"36"),
    (x"36", x"36", x"37", x"30", x"37", x"36", x"36", x"36"),
    (x"00", x"00", x"ff", x"00", x"ff", x"00", x"00", x"00"),
    (x"36", x"36", x"f7", x"00", x"f7", x"36", x"36", x"36"),
    (x"18", x"18", x"ff", x"00", x"ff", x"00", x"00", x"00"),
    (x"36", x"36", x"36", x"36", x"ff", x"00", x"00", x"00"),
    (x"00", x"00", x"ff", x"00", x"ff", x"18", x"18", x"18"),
    (x"00", x"00", x"00", x"00", x"ff", x"36", x"36", x"36"),
    (x"36", x"36", x"36", x"36", x"3f", x"00", x"00", x"00"),
    (x"18", x"18", x"1f", x"18", x"1f", x"00", x"00", x"00"),
    (x"00", x"00", x"1f", x"18", x"1f", x"18", x"18", x"18"),
    (x"00", x"00", x"00", x"00", x"3f", x"36", x"36", x"36"),
    (x"36", x"36", x"36", x"36", x"ff", x"36", x"36", x"36"),
    (x"18", x"18", x"ff", x"18", x"ff", x"18", x"18", x"18"),
    (x"18", x"18", x"18", x"18", x"f8", x"00", x"00", x"00"),
    (x"00", x"00", x"00", x"00", x"1f", x"18", x"18", x"18"),
    (x"ff", x"ff", x"ff", x"ff", x"ff", x"ff", x"ff", x"ff"),
    (x"00", x"00", x"00", x"00", x"ff", x"ff", x"ff", x"ff"),
    (x"f0", x"f0", x"f0", x"f0", x"f0", x"f0", x"f0", x"f0"),
    (x"0f", x"0f", x"0f", x"0f", x"0f", x"0f", x"0f", x"0f"),
    (x"ff", x"ff", x"ff", x"ff", x"00", x"00", x"00", x"00"),
    (x"00", x"00", x"76", x"dc", x"c8", x"dc", x"76", x"00"),
    (x"78", x"cc", x"cc", x"d8", x"cc", x"c6", x"cc", x"00"),
    (x"fe", x"c6", x"c0", x"c0", x"c0", x"c0", x"c0", x"00"),
    (x"00", x"00", x"fe", x"6c", x"6c", x"6c", x"6c", x"00"),
    (x"fe", x"c6", x"60", x"30", x"60", x"c6", x"fe", x"00"),
    (x"00", x"00", x"7e", x"d8", x"d8", x"d8", x"70", x"00"),
    (x"00", x"00", x"66", x"66", x"66", x"66", x"7c", x"c0"),
    (x"00", x"76", x"dc", x"18", x"18", x"18", x"18", x"00"),
    (x"7e", x"18", x"3c", x"66", x"66", x"3c", x"18", x"7e"),
    (x"38", x"6c", x"c6", x"fe", x"c6", x"6c", x"38", x"00"),
    (x"38", x"6c", x"c6", x"c6", x"6c", x"6c", x"ee", x"00"),
    (x"0e", x"18", x"0c", x"3e", x"66", x"66", x"3c", x"00"),
    (x"00", x"00", x"7e", x"db", x"db", x"7e", x"00", x"00"),
    (x"06", x"0c", x"7e", x"db", x"db", x"7e", x"60", x"c0"),
    (x"1e", x"30", x"60", x"7e", x"60", x"30", x"1e", x"00"),
    (x"00", x"7c", x"c6", x"c6", x"c6", x"c6", x"c6", x"00"),
    (x"00", x"fe", x"00", x"fe", x"00", x"fe", x"00", x"00"),
    (x"18", x"18", x"7e", x"18", x"18", x"00", x"7e", x"00"),
    (x"30", x"18", x"0c", x"18", x"30", x"00", x"7e", x"00"),
    (x"0c", x"18", x"30", x"18", x"0c", x"00", x"7e", x"00"),
    (x"0e", x"1b", x"1b", x"18", x"18", x"18", x"18", x"18"),
    (x"18", x"18", x"18", x"18", x"18", x"d8", x"d8", x"70"),
    (x"00", x"18", x"00", x"7e", x"00", x"18", x"00", x"00"),
    (x"00", x"76", x"dc", x"00", x"76", x"dc", x"00", x"00"),
    (x"38", x"6c", x"6c", x"38", x"00", x"00", x"00", x"00"),
    (x"00", x"00", x"00", x"18", x"18", x"00", x"00", x"00"),
    (x"00", x"00", x"00", x"18", x"00", x"00", x"00", x"00"),
    (x"0f", x"0c", x"0c", x"0c", x"ec", x"6c", x"3c", x"1c"),
    (x"6c", x"36", x"36", x"36", x"36", x"00", x"00", x"00"),
    (x"78", x"0c", x"18", x"30", x"7c", x"00", x"00", x"00"),
    (x"00", x"00", x"3c", x"3c", x"3c", x"3c", x"00", x"00"),
    (x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00")
    );

begin

  
  process(clk)
  begin
    if rising_edge(clk) then
      data_out <= font(to_integer(unsigned(char)))(to_integer(unsigned(char_line)));
    end if;
    
  end process;
  
end behave;
