-------------------------------------------------------------------------------
-- Title      : VGA Core
-- Project    : 
-------------------------------------------------------------------------------
-- File       : vgacore.vhd
-- Author     : 
-- Company    : 
-- Created    : 2007-10-16
-- Last update: 2009-05-29
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: 
-------------------------------------------------------------------------------
-- Copyright (c) 2007 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2007-10-16  1.0      Kest    Created
-------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.all;
use ieee.numeric_std.all;

entity vgacore_top is
  port (
    clk_m : in std_logic;
    clk_s : in std_logic;

    avm_chipselect    : out std_logic;
    avm_address       : out std_logic_vector(22 downto 0);
    avm_read          : out std_logic;
    avm_waitrequest   : in  std_logic;
    avm_readdata      : in  std_logic_vector(31 downto 0);
    avm_readdatavalid : in  std_logic;
    avm_write         : out std_logic;
    avm_writedata     : out std_logic_vector(31 downto 0);
    avm_byteenable    : out std_logic_vector(3 downto 0);

    avs_chipselect    : in  std_logic;
    avs_address       : in  std_logic_vector(19 downto 0);
    avs_read          : in  std_logic;
    avs_write         : in  std_logic;
    avs_readdata      : out std_logic_vector(31 downto 0);
    avs_writedata     : in  std_logic_vector(31 downto 0);
    avs_waitrequest   : out std_logic;
    avs_readdatavalid : out std_logic;


    -- extern
    clk_vga : in  std_logic;
    VGA_HS  : out std_logic;
    VGA_VS  : out std_logic;
    VGA_R   : out std_logic_vector(9 downto 0);
    VGA_G   : out std_logic_vector(9 downto 0);
    VGA_B   : out std_logic_vector(9 downto 0)



    );
end vgacore_top;

architecture behave of vgacore_top is

  component vgacore
    port (
      nReset     : in  std_logic;
      clk_24     : in  std_logic;
      VGA_Sync_o : out std_logic;
      VGA_DE     : out std_logic;
      VGA_HS     : out std_logic;
      VGA_VS     : out std_logic;
      VGA_R      : out std_logic_vector(3 downto 0);
      VGA_G      : out std_logic_vector(3 downto 0);
      VGA_B      : out std_logic_vector(3 downto 0));
  end component;


  component fifo_dual_clk
    port (
      aclr    : in  std_logic := '0';
      data    : in  std_logic_vector (31 downto 0);
      rdclk   : in  std_logic;
      rdreq   : in  std_logic;
      wrclk   : in  std_logic;
      wrreq   : in  std_logic;
      q       : out std_logic_vector (31 downto 0);
      rdempty : out std_logic;
      rdusedw : out std_logic_vector (7 downto 0);
      wrfull  : out std_logic;
      wrusedw : out std_logic_vector (7 downto 0));
  end component;


  component fifo_dual_clk_32x8
    port (
      aclr    : IN  STD_LOGIC := '0';
      data    : IN  STD_LOGIC_VECTOR (31 DOWNTO 0);
      rdclk   : IN  STD_LOGIC;
      rdreq   : IN  STD_LOGIC;
      wrclk   : IN  STD_LOGIC;
      wrreq   : IN  STD_LOGIC;
      q       : OUT STD_LOGIC_VECTOR (7 DOWNTO 0);
      rdempty : OUT STD_LOGIC;
      rdusedw : OUT STD_LOGIC_VECTOR (9 DOWNTO 0);
      wrfull  : OUT STD_LOGIC;
      wrusedw : OUT STD_LOGIC_VECTOR (7 DOWNTO 0));
  end component;
  
  signal VGA_Sync_o : std_logic;
  signal VGA_HS_int : std_logic;
  signal VGA_VS_int : std_logic;
  signal VGA_R_int  : std_logic_vector(3 downto 0);
  signal VGA_G_int  : std_logic_vector(3 downto 0);
  signal VGA_B_int  : std_logic_vector(3 downto 0);
  signal VGA_DE_int : std_logic;

  signal read_address : unsigned(avm_address'range) := (others => '0');

  signal fifo_aclr       : std_logic := '0';
  signal fifo_data       : std_logic_vector (31 downto 0);
  signal fifo_rdreq      : std_logic;
  signal fifo_wrreq      : std_logic;
  signal fifo_q          : std_logic_vector (7 downto 0);
  signal fifo_rdempty    : std_logic;
  signal fifo_rdusedw    : std_logic_vector (9 downto 0);
  signal fifo_wrfull     : std_logic;
  signal fifo_almostfull : std_logic;
  signal fifo_wrusedw    : std_logic_vector (7 downto 0);


--   signal aclr    : STD_LOGIC := '0';
--   signal data    : STD_LOGIC_VECTOR (31 DOWNTO 0);
--   signal rdclk   : STD_LOGIC;
--   signal rdreq   : STD_LOGIC;
--   signal wrclk   : STD_LOGIC;
--   signal wrreq   : STD_LOGIC;
--   signal q       : STD_LOGIC_VECTOR (7 DOWNTO 0);
--   signal rdempty : STD_LOGIC;
--   signal rdusedw : STD_LOGIC_VECTOR (9 DOWNTO 0);
--   signal wrfull  : STD_LOGIC;
--   signal wrusedw : STD_LOGIC_VECTOR (7 DOWNTO 0);

  
  signal VGA_Sync_d, VGA_Sync_d1, VGA_Sync_rise : std_logic;
  
begin

  avs_waitrequest   <= '0';
  avs_readdatavalid <= '0';

  avm_byteenable <= "1111";


  process(clk_m)
  begin
    if rising_edge(clk_m) then
      VGA_Sync_d  <= VGA_Sync_o;
      VGA_Sync_d1 <= VGA_Sync_d;
    end if;
  end process;

  VGA_Sync_rise <= VGA_Sync_d and not VGA_Sync_d1;

  process(clk_m)
  begin
    if rising_edge(clk_m) then

      if VGA_Sync_rise = '1' then
        read_address <= (others => '0');
      elsif fifo_wrreq='1' then
        read_address   <= read_address + 4;
      end if;
      
      if avm_waitrequest = '0' and fifo_almostfull = '0' then
        avm_chipselect <= '1';
        avm_read       <= '1';
        avm_address    <= std_logic_vector(read_address);
        
      elsif fifo_almostfull = '1' and avm_waitrequest='0' then
        avm_read       <= '0';
        avm_chipselect <= '0';
      end if;
      
    end if;

  end process;

  VGA_HS <= VGA_HS_int;
  VGA_VS <= VGA_VS_int;

  VGA_R <= (VGA_R_int & "000000") or (fifo_q(7 downto 6) & "00000000");
  VGA_G <= (VGA_G_int & "000000") or (fifo_q(5 downto 3) & "0000000");
  VGA_B <= (VGA_B_int & "000000") or (fifo_q(2 downto 0) & "0000000");


  fifo_aclr  <= VGA_Sync_rise;
  fifo_wrreq <= avm_readdatavalid and not fifo_wrfull;
  fifo_rdreq <= not fifo_rdempty and VGA_DE_int;

  fifo_data       <= avm_readdata;
  fifo_almostfull <= '1' when (unsigned(fifo_wrusedw) > 250) else '0';

  fifo_dual_clk_1 : fifo_dual_clk_32x8
    port map (
      aclr    => fifo_aclr,
      data    => fifo_data,
      rdclk   => clk_vga,
      rdreq   => fifo_rdreq,
      wrclk   => clk_m,
      wrreq   => fifo_wrreq,
      q       => fifo_q,
      rdempty => fifo_rdempty,
      rdusedw => fifo_rdusedw,
      wrfull  => fifo_wrfull,
      wrusedw => fifo_wrusedw);


  vgacore_1 : vgacore
    port map (
      nReset     => '1',
      clk_24     => clk_vga,
      VGA_Sync_o => VGA_Sync_o,
      VGA_DE     => VGA_DE_int,
      VGA_HS     => VGA_HS_int,
      VGA_VS     => VGA_VS_int,
      VGA_R      => VGA_R_int,
      VGA_G      => VGA_G_int,
      VGA_B      => VGA_B_int);

end behave;
